@@ -1,7 +1,4 @@
 
-from typing import Optional
-from typing import Any
-
 from deprecated import deprecated
 
 from logging import Logger
@@ -17,7 +14,7 @@ class PyutParameter(PyutObject):
 
     DEFAULT_PARAMETER_NAME: str = 'param'
 
-    def __init__(self, name: str = DEFAULT_PARAMETER_NAME, parameterType: PyutType = PyutType(""), defaultValue: Optional[Any] = None):
+    def __init__(self, name: str = DEFAULT_PARAMETER_NAME, parameterType: PyutType = PyutType(""), defaultValue: str = ''):
         """
 
         Args:
@@ -30,7 +27,7 @@ class PyutParameter(PyutObject):
         self.logger: Logger = getLogger(__name__)
 
         self._type:         PyutType = parameterType
-        self._defaultValue: Any      = defaultValue
+        self._defaultValue: str      = defaultValue
 
     @deprecated(reason='Use the properties')
     def getType(self) -> PyutType:
@@ -52,13 +49,11 @@ class PyutParameter(PyutObject):
         self._type = theType
 
     @deprecated(reason='Use the properties')
-    def getDefaultValue(self) -> Any:
-        """
-        """
+    def getDefaultValue(self) -> str:
         return self._defaultValue
 
     @deprecated(reason='Use the properties')
-    def setDefaultValue(self, defaultValue: Any):
+    def setDefaultValue(self, defaultValue: str):
         self._defaultValue = defaultValue
 
     @property
@@ -75,12 +70,12 @@ class PyutParameter(PyutObject):
         self._type = theType
 
     @property
-    def defaultValue(self) -> Any:
+    def defaultValue(self) -> str:
         return self._defaultValue
 
     @defaultValue.setter
-    def defaultValue(self, theNewValue: Any):
-        self._defaultValue = theNewValue
+    def defaultValue(self, newValue: str):
+        self._defaultValue = newValue
 
     def __str__(self) -> str:
         """
@@ -89,10 +84,13 @@ class PyutParameter(PyutObject):
         """
         s = self.name
 
-        if str(self._type) != "":
-            s = f'{s}: {self._type}'
+        if str(self._type.value) != "":
+            s = f'{s}: {self._type.value}'
 
-        if self._defaultValue is not None:
+        if self._defaultValue != '':
             s = f'{s} = {self._defaultValue}'
 
         return s
+
+    def __repr__(self) -> str:
+        return self.__str__()
\ No newline at end of file
